==> mod_blogxter0.9.0.jar: org/ten60/blogxter/active/BlogxterTrackbackParserAccessor.java <==
/******************************************************************************
  (c) Copyright 2003,2004, 1060 Research Ltd                                   

  This Software is licensed to You, the licensee, for use under the terms of   
  the 1060 Public License v1.0. Please read and agree to the 1060 Public       
  License v1.0 [www.1060research.com/license] before using or redistributing   
  this software.                                                               

  In summary the 1060 Public license has the following conditions.             
  A. You may use the Software free of charge provided you agree to the terms   
  laid out in the 1060 Public License v1.0                                     
  B. You are only permitted to use the Software with components or applications
  that provide you with OSI Certified Open Source Code [www.opensource.org], or
  for which licensing has been approved by 1060 Research Limited.              
  You may write your own software for execution by this Software provided any  
  distribution of your software with this Software complies with terms set out 
  in section 2 of the 1060 Public License v1.0                                 
  C. You may redistribute the Software provided you comply with the terms of   
  the 1060 Public License v1.0 and that no warranty is implied or given.       
  D. If you find you are unable to comply with this license you may seek to    
  obtain an alternative license from 1060 Research Limited by contacting       
  license@1060research.com or by visiting www.1060research.com                 

  NO WARRANTY:  THIS SOFTWARE IS NOT COVERED BY ANY WARRANTY. SEE 1060 PUBLIC  
  LICENSE V1.0 FOR DETAILS                                                     

  THIS COPYRIGHT NOTICE IS *NOT* THE 1060 PUBLIC LICENSE v1.0. PLEASE READ     
  THE DISTRIBUTED 1060_Public_License.txt OR www.1060research.com/license      

  File:          $RCSfile: BlogxterTrackbackParserAccessor.java,v $
  Version:       $Name:  $ $Revision: 1.2 $
  Last Modified: $Date: 2004/02/10 18:16:42 $
 *****************************************************************************/

package org.ten60.blogxter.active;

import org.ten60.netkernel.xml.xahelper.*;
import org.ten60.netkernel.xml.xda.*;
import org.ten60.netkernel.xml.representation.*;
import org.ten60.netkernel.xml.util.*;

import com.ten60.netkernel.urii.aspect.*;
import org.ten60.netkernel.layer1.representation.*;

import java.util.regex.*;
import java.io.*;
import org.w3c.dom.*;
import java.net.*;

/**
 *	Parses a trackback client request for the RDF trackback decsriptor.
 *	Since the result is not necessarily XHTML and the RDF may be hidden in a 
 *  HTML comment we have to do this all in the string domain ;-(
 * @author  pjr
 */
public class BlogxterTrackbackParserAccessor extends XAccessor
{	
	/** Creates a new instance of BlogxterTrackbackParser */
	public BlogxterTrackbackParserAccessor()
	{	declareArgument(OPERAND, true,false);
		declareArgument(OPERATOR, true,false);
	}
	
	protected com.ten60.netkernel.urii.IURRepresentation source(XAHelper aHelper) throws Throwable
	{	IAspectBinaryStream pagestream=(IAspectBinaryStream) aHelper.getOperand(IAspectBinaryStream.class).getAspect(IAspectBinaryStream.class);
		ByteArrayOutputStream baos=new ByteArrayOutputStream(4096);
		pagestream.write(baos);
		String page=baos.toString();
		Pattern p=Pattern.compile(".*(<rdf:RDF.*</rdf:RDF>).*", Pattern.DOTALL|Pattern.MULTILINE);
		Matcher m=p.matcher(page);
		String pingURI=null;
		String url=aHelper.getOperator().getXDA().getText("/uri", false);
		if(m.matches())
		{	for(int i=0; i<m.groupCount();i++)
			{	String rdf=m.group(i+1);
				int index=rdf.lastIndexOf(url);
				if(index>0)
				{	Document doc=XMLUtils.getInstance().parse(new StringReader(rdf));
					DOMXDA xda=new DOMXDA(doc,false);
					pingURI=xda.getText("/rdf:RDF/rdf:Description/@trackback:ping", true);
					break;
				}
			}
		}
		if(pingURI==null) throw new Exception("Trackback PING URI could not be found");
		URI uri=URI.create(pingURI);
		return URIAspect.create(aHelper.getDependencyMeta("text/xml", 8), uri);
	}
}

==> mod_blogxter1.0.1.jar: org/ten60/blogxter/active/BlogxterTrackbackParserAccessor.java <==
/******************************************************************************
  (c) Copyright 2003,2004, 1060 Research Ltd                                   

  This Software is licensed to You, the licensee, for use under the terms of   
  the 1060 Public License v1.0. Please read and agree to the 1060 Public       
  License v1.0 [www.1060research.com/license] before using or redistributing   
  this software.                                                               

  In summary the 1060 Public license has the following conditions.             
  A. You may use the Software free of charge provided you agree to the terms   
  laid out in the 1060 Public License v1.0                                     
  B. You are only permitted to use the Software with components or applications
  that provide you with OSI Certified Open Source Code [www.opensource.org], or
  for which licensing has been approved by 1060 Research Limited.              
  You may write your own software for execution by this Software provided any  
  distribution of your software with this Software complies with terms set out 
  in section 2 of the 1060 Public License v1.0                                 
  C. You may redistribute the Software provided you comply with the terms of   
  the 1060 Public License v1.0 and that no warranty is implied or given.       
  D. If you find you are unable to comply with this license you may seek to    
  obtain an alternative license from 1060 Research Limited by contacting       
  license@1060research.com or by visiting www.1060research.com                 

  NO WARRANTY:  THIS SOFTWARE IS NOT COVERED BY ANY WARRANTY. SEE 1060 PUBLIC  
  LICENSE V1.0 FOR DETAILS                                                     

  THIS COPYRIGHT NOTICE IS *NOT* THE 1060 PUBLIC LICENSE v1.0. PLEASE READ     
  THE DISTRIBUTED 1060_Public_License.txt OR www.1060research.com/license      

  File:          $RCSfile: BlogxterTrackbackParserAccessor.java,v $
  Version:       $Name:  $ $Revision: 1.3 $
  Last Modified: $Date: 2004/08/26 11:09:44 $
 *****************************************************************************/

package org.ten60.blogxter.active;

import org.ten60.netkernel.xml.xahelper.*;
import org.ten60.netkernel.xml.xda.*;
import org.ten60.netkernel.xml.representation.*;
import org.ten60.netkernel.xml.util.*;

import com.ten60.netkernel.urii.aspect.*;
import org.ten60.netkernel.layer1.representation.*;
import com.ten60.netkernel.urii.*;

import java.util.regex.*;
import java.io.*;
import org.w3c.dom.*;
import java.net.*;

/**
 *	Parses a trackback client request for the RDF trackback decsriptor.
 *	Since the result is not necessarily XHTML and the RDF may be hidden in a 
 *  HTML comment we have to do this all in the string domain ;-(
 * @author  pjr
 */
public class BlogxterTrackbackParserAccessor extends XAccessor
{	
	/** Creates a new instance of BlogxterTrackbackParser */
	public BlogxterTrackbackParserAccessor()
	{	declareArgument(OPERAND, true,false);
		declareArgument(OPERATOR, true,false);
	}
	
	protected com.ten60.netkernel.urii.IURRepresentation source(XAHelper aHelper) throws Exception
	{	IAspectBinaryStream pagestream=(IAspectBinaryStream) aHelper.getOperand(IAspectBinaryStream.class).getAspect(IAspectBinaryStream.class);
		ByteArrayOutputStream baos=new ByteArrayOutputStream(4096);
		pagestream.write(baos);
		String page=baos.toString();
		Pattern p=Pattern.compile(".*(<rdf:RDF.*</rdf:RDF>).*", Pattern.DOTALL|Pattern.MULTILINE);
		Matcher m=p.matcher(page);
		String pingURI=null;
		String url=aHelper.getOperator().getXDA().getText("/uri", false);
		if(m.matches())
		{	for(int i=0; i<m.groupCount();i++)
			{	String rdf=m.group(i+1);
				int index=rdf.lastIndexOf(url);
				if(index>0)
				{	Document doc=XMLUtils.getInstance().parse(new StringReader(rdf));
					DOMXDA xda=new DOMXDA(doc,false);
					pingURI=xda.getText("/rdf:RDF/rdf:Description/@trackback:ping", true);
					break;
				}
			}
		}
		if(pingURI==null) throw new Exception("Trackback PING URI could not be found");
		URI uri=URI.create(pingURI);
		URIAspect aspect=new URIAspect(uri);
		IURMeta meta=aHelper.getDependencyMeta("text/xml", 8);
		MonoRepresentationImpl rep=new MonoRepresentationImpl(meta, aspect);
		return rep;
	}
}
